@@ -10,6 +10,7 @@ from twitchbot import (
     channels,
     reload_whitelisted_commands,
     translate,
+    create_translate_callable,
 )
 
 MANAGE_COMMANDS_PERMISSION = 'manage_commands'
@@ -18,7 +19,7 @@ MANAGE_COMMANDS_PERMISSION = 'manage_commands'
 @Command('disablecmd',
          permission=MANAGE_COMMANDS_PERMISSION,
          syntax='<name>',
-         help='disables a command for the current channel')
+         help=create_translate_callable('builtin_command_help_message_disablecmd'))
 async def cmd_disable_cmd(msg: Message, *args):
     if not args:
         raise InvalidArgumentsError(reason=translate('missing_required_arguments'), cmd=cmd_disable_cmd)
@@ -40,7 +41,7 @@ async def cmd_disable_cmd(msg: Message, *args):
 @Command('enablecmd',
          permission=MANAGE_COMMANDS_PERMISSION,
          syntax='<name>',
-         help='enables a command for the current channel')
+         help=create_translate_callable('builtin_command_help_message_enablecmd'))
 async def cmd_enable_cmd(msg: Message, *args):
     if not args:
         raise InvalidArgumentsError(reason=translate('missing_required_arguments'), cmd=cmd_enable_cmd)
@@ -58,13 +59,13 @@ async def cmd_enable_cmd(msg: Message, *args):
     await msg.reply(translate('command_enabled', name=name))
 
 
-@Command('reloaddisabled', permission=MANAGE_COMMANDS_PERMISSION, help='reloads disable commands config')
+@Command('reloaddisabled', permission=MANAGE_COMMANDS_PERMISSION, help=create_translate_callable('builtin_command_help_message_reloaddisabled'))
 async def cmd_reload_disabled(msg: Message, *args):
     cfg_disabled_commands.load()
     await msg.reply(translate('reloaded_disabled_commands_config', user=msg.author))
 
 
-@Command('disablecmdglobal', permission=MANAGE_COMMANDS_PERMISSION, help='disables a command for all channels the bot is in')
+@Command('disablecmdglobal', permission=MANAGE_COMMANDS_PERMISSION, help=create_translate_callable('builtin_command_help_message_disablecmdglobal'))
 async def cmd_disable_command_global(msg: Message, *args):
     if not args:
         raise InvalidArgumentsError(reason=translate('missing_required_arguments'), cmd=cmd_disable_cmd)
@@ -83,7 +84,7 @@ async def cmd_disable_command_global(msg: Message, *args):
 @Command('enablecmdglobal',
          permission=MANAGE_COMMANDS_PERMISSION,
          syntax='<name>',
-         help='enables a command for all channels the bot is in')
+         help=create_translate_callable('builtin_command_help_message_enablecmdglobal'))
 async def cmd_enable_command_global(msg: Message, *args):
     if not args:
         raise InvalidArgumentsError(reason=translate('missing_required_arguments'), cmd=cmd_enable_cmd)
@@ -100,7 +101,7 @@ async def cmd_enable_command_global(msg: Message, *args):
 
 @Command('reloadcmdwhitelist',
          permission=MANAGE_COMMANDS_PERMISSION,
-         help='reloads whitelisted commands from the config file')
+         help=create_translate_callable('builtin_command_help_message_reloadcmdwhitelist'))
 async def cmd_reload_command_whitelist(msg: Message, *_):
     reload_whitelisted_commands()
     await msg.reply(translate('reloaded_command_whitelist', mention=msg.mention))
